/*
  ArdubotLib.cpp - Library for using Ardubot.Ru Module
*/
	
/*
 * Written by Konstantin Kostyuk et al., Jan 21, 2010.
 * Copyright (c) 2010 4Robots. For more information, see
 * Ver: 0.1
 *
 *   http://www.4Robots.ru
 *   http://www.Ardubot.ru
 *
 * You may freely modify and share this code, as long as you keep this
 * notice intact (including the two links above).  Licensed under the
 * Creative Commons BY-SA 3.0 license:
 *
 *   http://creativecommons.org/licenses/by-sa/3.0/
 *
 */

#ifndef F_CPU
#define F_CPU 8000000UL
#endif
#include <avr/io.h>
#include <stdlib.h>
#include "ArdubotLib.h"
#include "WProgram.h"
#include "wiring.h"		// provides access to delay() and delayMicroseconds()

// constructor

ArdubotMotors::ArdubotMotors()
{
	  pinMode(PIN_DIR_1A, OUTPUT);// sets the digital pin as output 
  	pinMode(PIN_PWM_2A, OUTPUT);// sets the digital pin as output 

	  pinMode(PIN_DIR_1B, OUTPUT);// sets the digital pin as output 
  	pinMode(PIN_PWM_2B, OUTPUT);// sets the digital pin as output 
  	
  	digitalWrite(PIN_DIR_1A, MOTOR_OFF);
  	analogWrite(PIN_PWM_2A, MOTOR_OFF);	
  	
  	digitalWrite(PIN_DIR_1B, MOTOR_OFF);
  	analogWrite(PIN_PWM_2B, MOTOR_OFF);		
}


// sets the motor speed.  The sign of 'speed' determines the direction
// and the magnitude determines the speed.  limits: -255 <= speed < 255
// |speed| = 255 produces the maximum speed while speed = 0 is full brake.
void ArdubotMotors::setM1Speed(int speed)
{
	unsigned char reverse = 0;

	if (speed < 0)
	{
		speed = -speed;	// make speed a positive quantity
		reverse = 1;	// preserve the direction
	}
	if (speed > 0xFF)	// 0xFF = 255
		speed = 0xFF;

	if (reverse)
	{
		OCR0B = 0;		// hold one driver input high
		OCR0A = speed;	// pwm the other input
	}
	else	// forward
	{
		OCR0B = speed;	// pwm one driver input
		OCR0A = 0;		// hold the other driver input high
	}
}


void ArdubotMotors::setM2Speed(int speed)
{
	unsigned char reverse = 0;

	if (speed < 0)
	{
		speed = -speed;	// make speed a positive quantity
		reverse = 1;	// preserve the direction
	}
	if (speed > 0xFF)	// 0xFF = 255
		speed = 0xFF;

	if (reverse)
	{
		OCR2B = 0;		// hold one driver input high
		OCR2A = speed;	// pwm the other input
	}
	else	// forward
	{
		OCR2B = speed;	// pwm one driver input
		OCR2A = 0;		// hold the other driver input high
	}
}


void ArdubotMotors::setSpeeds(int m1Speed, int m2Speed)
{
	setM1Speed(m1Speed);
	setM2Speed(m2Speed);
}
  
// Local Variables: **
// mode: C++ **
// c-basic-offset: 4 **
// tab-width: 4 **
// indent-tabs-mode: t **
// end: **
